==> parodia_admin-1.0.2.tar.gz: lib/core/repository/userGroup.repository.dart <==
// GET
// /api/v1/dashboard/users/groups/{id}

// PUT
// /api/v1/dashboard/users/groups/{id}

// DELETE
// /api/v1/dashboard/users/groups/{id}

// GET
// /api/v1/dashboard/users/groups

// POST
// /api/v1/dashboard/users/groups

// POST
// /api/v1/dashboard/users/groups/{id}/recover
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/dto/user_group.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class UserGroupRepository {
  ParodiaHTTP? _http;

  UserGroupRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<UserGroupDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/users/groups',
      param: id,
    );

    return ResponseItemDTO<UserGroupDTO>(
      response: response,
      fromJson: UserGroupDTO.fromJson,
    );
  }

  Future<ResponseListDTO<UserGroupDTO>> getAll({StoreQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/users/groups',
      query: query,
    );

    return ResponseListDTO<UserGroupDTO>(
      response: response,
      fromJson: UserGroupDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({UserGroupBody? userGroup}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/users/groups',
      data: userGroup,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, UserGroupBody? userGroup}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/users/groups',
      param: id,
      data: userGroup,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/users/groups',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/users/groups/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}

==> parodia_admin-1.0.20.tar.gz: lib/core/repository/userGroup.repository.dart <==
// GET
// /api/v1/dashboard/dashboard/users/groups/{id}

// PUT
// /api/v1/dashboard/dashboard/users/groups/{id}

// DELETE
// /api/v1/dashboard/dashboard/users/groups/{id}

// GET
// /api/v1/dashboard/dashboard/users/groups

// POST
// /api/v1/dashboard/dashboard/users/groups

// POST
// /api/v1/dashboard/dashboard/users/groups/{id}/recover
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/dto/user_group.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class UserGroupRepository {
  ParodiaHTTP? _http;

  UserGroupRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<UserGroupDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/users/groups',
      param: id,
    );

    return ResponseItemDTO<UserGroupDTO>(
      response: response,
      fromJson: UserGroupDTO.fromJson,
    );
  }

  Future<ResponseListDTO<UserGroupDTO>> getAll({StoreQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/users/groups',
      query: query,
    );

    return ResponseListDTO<UserGroupDTO>(
      response: response,
      fromJson: UserGroupDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({UserGroupBody? userGroup}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/users/groups',
      data: userGroup,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, UserGroupBody? userGroup}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/users/groups',
      param: id,
      data: userGroup,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/users/groups',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/users/groups/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
